/**
  ******************************************************************************
  * @file    LCD_SegmentsDrive/main.c
  * @author  MCD Application Team
  * @version V1.1.0
  * @date    01-July-2011
  * @brief   Main program body
  ******************************************************************************
  * @attention
  *
  */

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"
#include "main.h"

  // * @addtogroup LCD_SegmentsDrive

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Peripheral InitStructure define 
RTC_InitTypeDef   RTC_InitStr;
RTC_TimeTypeDef   RTC_TimeStr;
__IO uint8_t LCDStringTime[6];
uint8_t Position = 0x00;
__IO ButtonStatus_TypeDef PressedButton = BUTTON_RELEASED;
__IO uint8_t ValueMax = 0x00;
// Private function prototypes -----------------------------------------------
#ifdef USE_STM8L1528_EVAL
 void LCD_GLASS_DisplaySTM(void);
#endif /* USE_STM8L1528_EVAL */
// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
  // Enable RTC clock 
  CLK_PeripheralClockConfig(CLK_Peripheral_RTC, ENABLE);

  // De-initialize the RTC
  RTC_DeInit();

  // Configures the RTC 
  RTC_WakeUpClockConfig(RTC_WakeUpClock_RTCCLK_Div16);
  /* RTC will wake-up from halt every 0.5s
  RTCClk =32768Hz
  Wakeup tick  =32768Hz/16 = 2048Hz = 0.000488 s
  0.000488 x 1024 = 0.5s */
  RTC_SetWakeUpCounter(0x400);
  RTC_ITConfig(RTC_IT_WUT, ENABLE);

  // Initialize push-buttons mounted on STM8L1526-EVAL board 
  GPIO_Init(KEY_BUTTON_PORT, KEY_BUTTON_PIN, GPIO_Mode_In_FL_IT);
  EXTI_SetPinSensitivity(KEY_BUTTON_EXTI, EXTI_Trigger_Rising_Falling);


  // Initialize the interrupts priority 
  ITC_SetSoftwarePriority(TIM2_UPDATE_IRQn, ITC_PriorityLevel_1);
  ITC_SetSoftwarePriority(KEY_BUTTON_EXTI_IRQn, ITC_PriorityLevel_0);

  // Configures the LCD GLASS relative GPIO port IOs and LCD peripheral
  LCD_GLASS_Init();

  // Initialize time application 
  Calendar_Init();

  // TIMER2 initialization for generic timebase 
  TimingDelay_Init();

  // Enable general Interrupt
  enableInterrupts();

#ifdef USE_STM8L1528_EVAL
  LCD_GLASS_DisplaySTM();
  // Enable the display for the ST Logo 
  LCD_GLASS_DisplayLogo(ENABLE);
#endif /* USE_STM8L1528_EVAL */

  // Display current time 
  LCD_ShowTimeCalendar();

  // Time setting 
  Time_Regulate();

  // Clear the LCD Glass position 7 as it not used in the application 
  LCD_GLASS_ClearChar(Position);

  RTC_WakeUpCmd(ENABLE);

  /* Force the remaining I/O's into pull up configuration (except I2C) to avoid an
     extra consumption.*/

#ifdef USE_STM8L1526_EVAL
  GPIO_ExternalPullUpConfig(GPIOA, GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3, ENABLE);
  GPIO_ExternalPullUpConfig(GPIOC, GPIO_Pin_5 | GPIO_Pin_6, ENABLE);
  GPIO_ExternalPullUpConfig(GPIOF, GPIO_Pin_0, ENABLE);
#else /* USE_STM8L1528_EVAL */
  GPIO_ExternalPullUpConfig(GPIOA, GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3, ENABLE);
  GPIO_ExternalPullUpConfig(GPIOB, GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_6, ENABLE);
  GPIO_ExternalPullUpConfig(GPIOC, GPIO_Pin_5 | GPIO_Pin_6, ENABLE);
  GPIO_ExternalPullUpConfig(GPIOF, GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3, ENABLE);
  GPIO_ExternalPullUpConfig(GPIOH, GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_7, ENABLE);
  GPIO_ExternalPullUpConfig(GPIOI, GPIO_Pin_0, ENABLE);
#endif /* USE_STM8L1526_EVAL */

  while (1)
  {
    LCD_ShowTimeCalendar();
    halt();
  }
}

/**
  * @brief  Initializes calendar application.
  * @param  None
  * @retval None
  */
void Calendar_Init(void)
{
  RTC_InitStr.RTC_HourFormat = RTC_HourFormat_24;
  RTC_InitStr.RTC_AsynchPrediv = 0x7F;
  RTC_InitStr.RTC_SynchPrediv = 0x00FF;
  RTC_Init(&RTC_InitStr);

  RTC_TimeStr.RTC_H12     = RTC_H12_AM;
  RTC_TimeStr.RTC_Hours   = 00;
  RTC_TimeStr.RTC_Minutes = 00;
  RTC_TimeStr.RTC_Seconds = 00;
  RTC_SetTime(RTC_Format_BIN, &RTC_TimeStr);
}

/**
  * @brief  Update the time entered by user, using demo board keys.
  * @param  None
  * @retval None
  */
void Time_Regulate(void)
{
  uint8_t tmphh = 0, tmpmm = 0, tmpss = 0 , temp = 0;
  uint8_t tmpvalue, count, index = 0x00;

  for (count = 0x00; count < 0x06; count++)
  {
    LCDStringTime[count] = 0x30;
  }

  while (Position < 6)
  {
    // Insert 400 ms delay 
    Delay(400);
    // Check if Key button released 
    if (GPIO_ReadInputDataBit(KEY_BUTTON_PORT, KEY_BUTTON_PIN) != Bit_RESET)
    {
      if (index == 0)
      {
        LCD_GLASS_ClearChar(Position);
        index++;
      }
      else
      {
        if ((Position == 2) || (Position == 4))
        {
          LCD_GLASS_WriteChar((uint8_t*)(&LCDStringTime[Position]), POINT_OFF, SEPARATOR_ON, Position);
        }
        else
        {
          LCD_GLASS_WriteChar((uint8_t*)&LCDStringTime[Position], POINT_OFF, SEPARATOR_OFF, Position);
        }
        index = 0x00;
      }
    }
    // Check if Key button is pressed
    if (GPIO_ReadInputDataBit(KEY_BUTTON_PORT, KEY_BUTTON_PIN) == Bit_RESET)
    {
      // Initialize tmpvalue 
      tmpvalue = LCDStringTime[Position];
      // Display  
      tmpvalue -= 0x30;
      // Increase the value of the digit 
      if (tmpvalue >= ValueMax)
      {
        tmpvalue = 0x00;
      }
      else
      {
        tmpvalue++;
      }
      LCDStringTime[Position] = (uint8_t)(tmpvalue + 0x30);
      if ((Position == 2) || (Position == 4))
      {
        LCD_GLASS_WriteChar((uint8_t*)&LCDStringTime[Position], POINT_OFF, SEPARATOR_ON, Position);
      }
      else
      {
        LCD_GLASS_WriteChar((uint8_t*)&LCDStringTime[Position], POINT_OFF, SEPARATOR_OFF, Position);
      }
    }
  }

  GPIO_Init(KEY_BUTTON_PORT, KEY_BUTTON_PIN, GPIO_Mode_In_FL_No_IT);
  TIM2_Cmd(DISABLE);

  // Read time hours 
  temp = (uint8_t)(LCDStringTime[1] - 0x30);
  tmphh = (uint8_t)((LCDStringTime[0] - 0x30) * 10 + temp);
  // Read time  minutes 
  temp = (uint8_t)(LCDStringTime[3] - 0x30);
  tmpmm = (uint8_t)((LCDStringTime[2] - 0x30) * 10 + temp);
  // Read time seconds 
  temp = (uint8_t)(LCDStringTime[5] - 0x30);
  tmpss = (uint8_t)((LCDStringTime[4] - 0x30) * 10 + temp);

  // Set the Time 
  RTC_TimeStr.RTC_Hours   = tmphh;
  RTC_TimeStr.RTC_Minutes = tmpmm;
  RTC_TimeStr.RTC_Seconds = tmpss;
  RTC_SetTime(RTC_Format_BIN, &RTC_TimeStr);
}

/**
  * @brief  Prints the Time Calender on the GLASS LCD.
  * @param  None
  * @retval None
  */
void LCD_ShowTimeCalendar(void)
{
  uint8_t tmp = 0;

  // Wait for RTC registers synchronisation 
  RTC_WaitForSynchro();

  // Get the current Time
  RTC_GetTime(RTC_Format_BCD, &RTC_TimeStr);

  tmp = (char)(((uint8_t)(RTC_TimeStr.RTC_Hours & 0xF0) >> 4) + 48);
  LCD_GLASS_WriteChar(&tmp, POINT_OFF, SEPARATOR_OFF, 0);

  tmp = (char)(((uint8_t)(RTC_TimeStr.RTC_Hours & 0x0F)) + 48);
  LCD_GLASS_WriteChar(&tmp, POINT_OFF, SEPARATOR_OFF, 1);

  tmp = (char)(((uint8_t)(RTC_TimeStr.RTC_Minutes & 0xF0) >> 4) + 48);
  LCD_GLASS_WriteChar(&tmp, POINT_OFF, SEPARATOR_ON, 2);

  tmp = (char)(((uint8_t)(RTC_TimeStr.RTC_Minutes & 0x0F)) + (uint8_t)48);
  LCD_GLASS_WriteChar(&tmp, POINT_OFF, SEPARATOR_OFF, 3);

  tmp = (char)(((uint8_t)(RTC_TimeStr.RTC_Seconds & 0xF0) >> 4) + 48);
  LCD_GLASS_WriteChar(&tmp, POINT_OFF, SEPARATOR_ON, 4);

  tmp = (char)(((uint8_t)(RTC_TimeStr.RTC_Seconds & 0x0F)) + 48);
  LCD_GLASS_WriteChar(&tmp, POINT_OFF, SEPARATOR_OFF, 5);
}

/**
  * @brief  Configure the max value for the calendar digit.
  * @param  Calendar digit position in the LCD string time
  * @retval None
  */
void LCD_MaxValueConfig(uint8_t Position)
{
  switch (Position)
  {
    case 0:
      ValueMax = 0x02;
      break;
    case 2:
      ValueMax = 0x05;
      break;
    case 4:
      ValueMax = 0x05;
      break;
    default:
      ValueMax = 0x09;
      break;
  }
  if ((Position == 1) && (LCDStringTime[0] == 0x32))
  {
    ValueMax = 0x03;
  }
}

#ifdef USE_STM8L1528_EVAL
/**
  * @brief  Set all Pixel in the Matrix ON
  * @param  None
  * @retval None
  */
void LCD_GLASS_DisplaySTM(void)
{
  // Set Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_1);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_2);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_3);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_4);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_5);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_6);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_7);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_8);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_9);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_10);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_11);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_12);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_13);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_14);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_15);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_16);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_17);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_18);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_1, PIXELCOLUMN_19);

  // Set Row2 Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_2, PIXELCOLUMN_1);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_2, PIXELCOLUMN_2);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_2, PIXELCOLUMN_3);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_2, PIXELCOLUMN_11);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_2, PIXELCOLUMN_14);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_2, PIXELCOLUMN_15);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_2, PIXELCOLUMN_16);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_2, PIXELCOLUMN_19);

  // Set Row3 Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_1);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_2);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_4);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_5);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_6);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_7);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_9);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_10);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_11);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_13);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_15);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_17);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_3, PIXELCOLUMN_19);

  // Set Row4 Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_1);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_2);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_4);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_5);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_6);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_7);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_9);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_10);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_11);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_13);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_15);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_17);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_4, PIXELCOLUMN_19);

  // Set Row5 Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_1);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_2);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_3);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_6);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_7);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_9);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_10);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_11);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_13);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_14);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_16);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_17);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_5, PIXELCOLUMN_19);

  // Set Row6 Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_1);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_2);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_3);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_4);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_5);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_7);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_9);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_10);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_11);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_13);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_14);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_15);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_16);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_17);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_6, PIXELCOLUMN_19);

  // Set Row7 Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_1);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_2);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_3);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_4);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_5);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_7);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_9);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_10);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_11);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_13);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_14);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_15);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_16);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_17);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_7, PIXELCOLUMN_19);

  // Set Row8 Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_1);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_2);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_3);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_4);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_5);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_7);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_9);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_10);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_11);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_13);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_14);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_15);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_16);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_17);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_8, PIXELCOLUMN_19);

  // Set All Row9 Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_1);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_6);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_7);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_9);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_10);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_11);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_13);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_14);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_15);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_16);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_17);

  LCD_GLASS_WriteMatrixPixel(PIXELROW_9, PIXELCOLUMN_19);

  // Set All Row10 Pixels On 
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_1);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_2);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_3);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_4);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_5);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_6);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_7);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_8);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_9);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_10);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_11);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_12);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_13);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_14);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_15);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_16);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_17);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_18);
  LCD_GLASS_WriteMatrixPixel(PIXELROW_10, PIXELCOLUMN_19);

}
#endif /* USE_STM8L1528_EVAL */

#ifdef  USE_FULL_ASSERT
/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {}
}
#endif


